SameNumberOfRows

Trait SameNumberOfRows 

pub trait SameNumberOfRows<D1, D2>: DimEq<D1, D2> + DimEq<D2, D1>
where D1: Dim, D2: Dim,
{ type Representative: Dim; // Provided method fn representative(d1: D1, d2: D2) -> Option<Self::Representative> { ... } }
Constrains D1 and D2 to be equivalent. They are both assumed to be the number of rows of a matrix.

Required Associated Types

type Representative: Dim

This is either equal to D1 or D2, always choosing the one (if any) which is a type-level constant.

Provided Methods

fn representative(d1: D1, d2: D2) -> Option<Self::Representative>

Returns a representative dimension instance if the two are equal, otherwise None.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors